@@ -104,7 +104,7 @@ void reconnect()
 	case OER_RECONNECT_ERROR:
 		if(mystate->quitting) {
 #ifdef DEBUG
-			oer_debug(OER_DEBUG_INFO, "reconnect->%s exiting\n", mystate->progname);
+			oer_debug(OER_DEBUG_INFO, "reconnect->oer exiting\n");
 #endif
 			close(mystate->sockfd);
 			exit(EXIT_SUCCESS);
