@@ -353,7 +353,7 @@ enum OER_FLAGS_TYPE {
 #define OER_NICKCHANGES 20
 #define OER_TOPICS 10
 #define OER_SERVER_IS_STONED_FOR 300
-#define OER_LINENOISE_INTERVAL_MIN 1
+#define OER_LINENOISE_INTERVAL_MIN 0
 #define OER_MASSMODE_LIMIT 3
 #define OER_LAST 3
 #define OER_LAST_MAX 10
@@ -403,7 +403,7 @@ enum OER_FLAGS_TYPE {
 #define USERLEN 16
 #define NICKLEN 20
 #define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
-#define TOPICLEN 160
+#define TOPICLEN 250
 #define TOPIC_SEPARATOR " | "
 #define CONNECTION_STATE_PREFIXES "^~+=-"
 #define OER_MAX_LIST_LINES 5
@@ -414,7 +414,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define OER_REALNAME "http://oer.equnet.org"
-#define OER_VERSION "oer version 1.0-60"
+#define OER_VERSION "oer version 1.0-61"
 #define OER_COPYRIGHT1 "Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
@@ -498,6 +498,7 @@ struct authed {
 struct topic {
 	time_t at;
 	int list;
+	int deleted;
 	char *setby;
 	char *topic;
 	struct topic *prev;
@@ -671,7 +672,8 @@ struct channel {
 };
 
 struct state {
-	char progname[STRINGLEN + 1];
+	char basedir[STRINGLEN + 1];
+	char progname[TINYSTRINGLEN + 1];
 	char altloggingdir[STRINGLEN + 1];
 	/* this is our current nick, might be temporarily set
 	   to getnick when attempting to change nick */
