@@ -293,13 +293,12 @@ void parseirc(char *serveroutput)
 				continue;
 			}
 			ptr[0] = '\0';
+			/* reset user's flags */
+			changeuser(this, temp_nick, -1, 0, 0, -1);
 			if(index(channel, (int)'@')) {
 				/* @ can hide + -> set @, assume + */
 				changeuser(this, temp_nick, -1, 1, 1, -1);
 			}
-			if(index(channel, (int)'*')) {
-				changeuser(this, temp_nick, 1, -1, -1, -1);
-			}
 			if(index(channel, (int)'+')) {
 				changeuser(this, temp_nick, -1, -1, 1, -1);
 			}
@@ -1038,13 +1037,9 @@ void parseirc(char *serveroutput)
 					getnthmode(mode, i + 1, modeline);
 					if(!strcasecmp(modeline, "+k")) {
 						strncpy(this->key, target, CHANLEN);
-						snprintf(outstring, STRINGLEN, "%s channel key is now %s", this->name, this->key);
-						sendreply(this->name, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 					}
 					if(!strcasecmp(modeline, "-k")) {
 						memset(this->key, 0, CHANLEN + 1);
-						snprintf(outstring, STRINGLEN, "deleted channel key from %s", this->name);
-						sendreply(this->name, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 					}
 #ifdef DEBUG
 					oer_debug(OER_DEBUG_NOISE, "parseirc(MODE)->target is %s\n", target);
@@ -1423,7 +1418,6 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 	char outstring2[WRITE_BUFFER_LENGTH + 1];
 	char command[STRINGLEN + 1];
 	char channel[CHANLEN + 1];
-	char topic[TOPICLEN + 1];
 	char uptimestring[STRINGLEN + 1];
 	char modeline[CHANLEN + 1];
 	char ts[TINYSTRINGLEN + 1];
@@ -1530,11 +1524,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(!checkauth(this, userhost, nick, tochan, 0)) {
 			return;
 		}
-		if(deltopic(this, atoi(restptr), topic) == NULL) {
-			return;
-		}
-		snprintf(outstring, WRITE_BUFFER_LENGTH, "deleted Topic #%d: %s", atoi(restptr), topic);
-		sendreply((tochan) ? this->name : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
+		deltopic(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
 		return;
 	case OER_WHICHCOMMAND_TOPIC_EDIT:
 #ifdef DEBUG
@@ -2482,6 +2472,9 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		for(cb = this->channelbans; cb != NULL; cb = cb->next) {
+			if(ispermban(this, cb->ban)) {
+				continue;
+			}
 			mmode_new(this, mystate->now, "-b", cb->ban);
 			delchannelban(this, cb->ban);
 		}
@@ -2497,7 +2490,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 #ifdef DEBUG
-		oer_debug(OER_DEBUG_INFO, "parsecommand)->cycling %s because %s!%s ordered me to\n", this->name, nick, userhost);
+		oer_debug(OER_DEBUG_INFO, "parsecommand->cycling %s because %s!%s ordered me to\n", this->name, nick, userhost);
 #endif
 		snprintf(timed_str, WRITE_BUFFER_LENGTH, "PART %s", this->name);
 		timed_new(NULL, mystate->now, OER_TIMED_TYPE_NORMAL, OER_TIMED_PRIORITY_CHANNEL_HANDLING, timed_str);
